==> filemv0.52.6.zip: source/status.cpp <==

#include "defextern.h"


#ifndef STRICT
    #define STRICT
#endif
#include <stdio.h>
#include <windows.h>
#include "resource.h"
#include "myfilemv.h"
#include "main.h"
#include "status.h"
#include "paintflag.h"
#include "initial.h"
#include "tab.h"
#include "mode.h"

char mes[MAX_PATH]="";

int posPos=3;
int posFile=2;
int posLeft=0;

void settitle(HWND &hWnd)
{
	int t=GetNTab();
	char *p=GetNPath();
	char *pf=GetNFile();
	if (p==NULL || pf==NULL) return;
	if(MemoMode == _ON)
	{
		wsprintf(title,"%s :memo-mode %s / %s" ,&appname ,memopath, memofile);
	}
	else if(showpathTitle) 
	{
		if( t ==tab_l) wsprintf(title,"%s ( %s / %s" ,&appname ,p ,pf );
		if( t ==tab_r) wsprintf(title,"%s ) %s / %s" ,&appname ,p ,pf );
	}
	else wsprintf(title,"%s" ,&appname);
	SetWindowText(hWnd, title);
}

void settitle(HWND &hWnd, char *d, int tab)
{
	char *p=d;
	if (p==NULL ) return;
	if(MemoMode == _ON)
	{
		wsprintf(title,"%s :memo: %s"  ,&appname, memofile);
	}
	else if(showpathTitle) 
	{
		if( tab ==tab_l) wsprintf(title,"%s ( %s" ,&appname ,p );
		if( tab ==tab_r) wsprintf(title,"%s ) %s" ,&appname ,p );
	}
	else wsprintf(title,"%s" ,&appname);
	SetWindowText(hWnd, title);
}

void resettitle(HWND &hWnd)
{
	settitle(hWnd);
}

void resettitle()
{
	settitle(hmainwnd);
}

void resettitle(char *d, int tab)
{
	settitle(hmainwnd, d, tab);
}


void setstatusbyte(char *mes)
{
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)posLeft | 0, (LPARAM)mes);
}

void setstatusnum(DWORD num)
{
	wsprintf(mes,"%d",num);
	setstatus(mes);
}

void setstatusnum(int num,int all)
{
	wsprintf(mes,"%d/%d",num,all);
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)posLeft | 0, (LPARAM)mes);
}

void setstatusspace(int num,int all, double space, double total)
{
	if(space<1000) sprintf(mes,"%d %.fMfree/%.fM", all, space,total);
	else sprintf(mes,"%d %10.2fGfree/%.2fG", all, space/1024,total/1024);
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)posLeft | 0, (LPARAM)mes);
}



void setstatusonly(char *mes)
{
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)posFile | 0, (LPARAM)mes);
}


void setstatusonly(int pos,char *mes)
{
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)pos | 0, (LPARAM)mes);
}

void setstatusfullpath(char *file)
{
	_fullpath(mes,file,MAX_PATH);
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)posFile | 0, (LPARAM)mes);
}


void setstatusMousepos(int num, int x, int y)
{
	wsprintf(mes,"%d:%d,%d",num, x,y);
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)posPos | 0, (LPARAM)mes);
}

void setstatusMousepos(int x)
{
	wsprintf(mes,"%d",x);
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)posPos | 0, (LPARAM)mes);
}

// logɂ

void setstatus(char *mes)
{
	if(mes==NULL) return;
	if(strlen(mes)==0) return;
	SYSTEMTIME st;
	char jikan[10];
	char form[]="%02d:%02d:%02d";

	GetLocalTime(&st);
	wsprintf(
		jikan,
		form,
	
		st.wHour,
		st.wMinute,
		st.wSecond
	);
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)posFile | 0, (LPARAM)mes);
	if(logflag) log<<jikan<<" "<<mes<<endl;//if(*log!=NULL) *
}

void setstatus(int i)
{
	wsprintf(mes,"%d",i);
	setstatus(mes);
}
void setstatus(int i,int j)
{
	wsprintf(mes,"%d,%d",i,j);
	setstatus(mes);
}

void setstatus(int i,int j,int k)
{
	wsprintf(mes,"%d,%d,%d",i,j,k);
	setstatus(mes);
}

void logwrite(char *str, char *str2)
{
	if(logflag) log<<str<<","<<str2<<endl;//if(*log!=NULL) *
}

void logwrite(char *str)
{
	if(logflag) log<<str<<endl;
}


void logwrite(short i, short j)
{
	if(logflag) log<<i<<","<<j<<endl;//if(*log!=NULL) *
}

void setstatus(char *mes,char *m2)
{
	wsprintf(::mes,"%s %s", mes, m2);
	SendMessage(hStatus, SB_SETTEXT,
		(WPARAM)posFile | 0, (LPARAM)::mes);
}



int Mes(char *m)
{
	return MessageBox(NULL, m, "!", MB_OKCANCEL);
}
int Mes(int i)
{
	char *buffer=mes;
	wsprintf(buffer,"%d",i);
	return MessageBox(NULL, buffer, "!", MB_OK);
}

==> filemv0.362.0.0.zip: source/status.cpp <==

#include "defextern.h"


#ifndef STRICT
    #define STRICT
#endif
#include <stdio.h>
#include <fstream.h>
#include <windows.h>
#include <windowsx.h>
//#include "dir.h"
#include "resource.h"
#include "myfilemv.h"
#include "main.h"
#include "status.h"
#include "paintflag.h"


void settitle(HWND &hWnd)
{
	wsprintf(title,"%s " ,&appname  );
	SetWindowText(hWnd, title);
}

void resettitle(HWND &hWnd)
{
	settitle(hWnd);
}
void resettitle()
{
	settitle(hmainwnd);
}


void setstatusbyte(char *mes)
{
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)0 | 0, (LPARAM)mes);
}

void setstatusnum(DWORD num)
{
	char mes[MAX_PATH];
	wsprintf(mes,"%d",num);
	setstatus(mes);
}

void setstatusnum(int num,int all)
{
	char mes[MAX_PATH];
	wsprintf(mes,"%d/%d",num,all);
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)0 | 0, (LPARAM)mes);
}

void setstatusspace(int num,int all, double space, double total)
{
	char mes[MAX_PATH];
	if(space<1000) sprintf(mes,"%d %.fMfree/%.fM", all, space,total);
	else sprintf(mes,"%d %10.2fGfree/%.2fG", all, space/1024,total/1024);
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)0 | 0, (LPARAM)mes);
}



void setstatusonly(char *mes)
{
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)2 | 0, (LPARAM)mes);
}


void setstatusonly(int pos,char *mes)
{
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)pos | 0, (LPARAM)mes);
}

void setstatusfullpath(char *file)
{
	char mes[MAX_PATH];
	_fullpath(mes,file,MAX_PATH);
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)2 | 0, (LPARAM)mes);
}


void setstatus(char *mes)
{
	if(mes==NULL) return;
	if(strlen(mes)==0) return;
	SYSTEMTIME st;
	char jikan[10];
	char form[]="%02d:%02d:%02d";

	GetLocalTime(&st);
	wsprintf(
		jikan,
		form,
	
		st.wHour,
		st.wMinute,
		st.wSecond
	);
	SendMessage(hStatus, SB_SETTEXT,
                        (WPARAM)2 | 0, (LPARAM)mes);
	if(logflag) log<<jikan<<" "<<mes<<endl;//if(*log!=NULL) *
}
